@@ -1,8 +1,9 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # this tests the entities substitutions with the XmlTextReader interface
 #
 import sys
+import setup_test
 import libxml2
 
 # Memory debug specific
@@ -33,4 +34,3 @@ if libxml2.debugMemory(1) == 0:
     print("OK")
 else:
     print("Memory leak %d bytes" % (libxml2.debugMemory(1)))
-    libxml2.dumpMemory()
